@@ -5,7 +5,7 @@
    driver classes/backends. All virtual functions have to be implemented by
    the specific driver class. See drvSAMPL.cpp
   
-   Copyright (C) 1993 - 2005 Wolfgang Glunz, wglunz34_AT_pstoedit.net
+   Copyright (C) 1993 - 2011 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -146,7 +146,8 @@ class       DLLEXPORT    drvbase
 public:
 	// = PUBLIC TYPES 
 
-	enum showtype { stroke, fill, eofill }; //lint -esym(578,drvbase::fill)
+	//lint -esym(578,drvbase::fill,fill)
+	enum showtype { stroke, fill, eofill }; 
 	enum cliptype { clip , eoclip };
 	enum linetype { solid=0, dashed, dotted, dashdot, dashdotdot }; // corresponding to the CGM patterns
 	struct DLLEXPORT TextInfo {
@@ -156,6 +157,7 @@ public:
 		float 		x_end; // pen coordinates after show in PostScript
 		float		y_end; // 
 		RSString 	thetext;
+		RSString	glyphnames;
 		bool		is_non_standard_font;
 		RSString    currentFontName;
 		RSString    currentFontFamilyName;
@@ -166,6 +168,7 @@ public:
 		float       currentR; // Colors
 		float       currentG;
 		float       currentB;
+		RSString    colorName; // extracted from PostScript colorspace if /Separation type
 		float		cx; // next five items correspond to the 
 		float		cy; // params for the awidthshow operator
 		int			Char; // of PostScript
@@ -199,6 +202,7 @@ public:
 			currentR(0.0f),
 			currentG(0.0f),
 			currentB(0.0f),
+			colorName(""),
 			cx(0.0f),
 			cy(0.0f),
 			Char(32), // 32 means space
@@ -241,8 +245,9 @@ protected:
 		float           fillR; // fill colors
 		float           fillG;
 		float           fillB;
+		RSString		colorName;
 		bool			pathWasMerged; // true, if this path is a result of a merge operation
-		RSString	dashPattern; // just the dump of currentdash as string
+		RSString	    dashPattern; // just the dump of currentdash as string
 		PathInfo() :
 			currentShowType(drvbase::stroke),
 			currentLineType(drvbase::solid),
@@ -251,7 +256,7 @@ protected:
 			currentMiterLimit(10.0f),
 			nr(0),
 			path(0),
-			isPolygon(0),
+			isPolygon(false),
 			numberOfElementsInPath(0),
 			subpathoffset(0),
 			currentLineWidth(0.0f),
@@ -261,6 +266,7 @@ protected:
 			fillR(0.0f),
 			fillG(0.0f),
 			fillB(0.0f),
+			colorName(""),
 			pathWasMerged(false),
 			dashPattern(emptyDashPattern)
 			{
@@ -314,7 +320,7 @@ public:
 
 	static bool Verbose();  // need a wrapper function because static initialized data cannot be DLLEXPORTed
 	static void SetVerbose(bool param);
-	static unsigned int totalNumberOfPages;
+	static unsigned int &totalNumberOfPages();
 	
 	static BBox	* bboxes() ; // [maxPages]; // array of bboxes - maxpages long
 	static RSString& pstoeditHomeDir(); // usually the place where the binary is installed
@@ -328,12 +334,12 @@ protected:
 	const RSString	inFileName; // full name of input file
 	const RSString	outFileName; // full name of output file
 
-	char*         	outDirName; 	// output path with trailing slash or backslash
-	char*         	outBaseName; 	// just the basename (no path, no suffix)
+	RSString       	outDirName; 	// output path with trailing slash or backslash
+	RSString       	outBaseName; 	// just the basename (no path, no suffix)
 	unsigned int	d_argc;
 	const char **			d_argv; // array of driver argument strings
 	const class PsToEditOptions & globaloptions; 
-	float           currentDeviceHeight; // normally 792 pt; used for flipping y values.
+	float           currentDeviceHeight; // normally 792 pt (US Letter); used for flipping y values.
 	float           currentDeviceWidth;  
 	float           x_offset;
 	float           y_offset;
@@ -352,7 +358,7 @@ private:
 	static bool	verbose; // access via Verbose() 
 	bool    	page_empty;	// indicates whether the current page is empty or not
 	char * 		driveroptions; // string containing options for backend
-	PathInfo 	p1,p2,clippath; // p1 and p2 are filled alternatively (to allow merge), clippath when a clippath is read
+	PathInfo 	PI1,PI2,clippath; // pi1 and pi2 are filled alternatively (to allow merge), clippath when a clippath is read
 	PathInfo * 	currentPath; // for filling from lexer
 	PathInfo * 	last_currentPath; // need to save during usage of currentPath for clippath
 protected: // for drvrtf
@@ -397,7 +403,7 @@ public:
 
 	void		setdefaultFontName(const char * n) {defaultFontName = n;}
 
-	virtual bool textIsWorthToPrint(const char *thetext) const; // in the default implementation full blank strings are ignored
+	virtual bool textIsWorthToPrint(const RSString & thetext) const; // in the default implementation full blank strings are ignored
 
 	virtual bool textCanBeMerged(const TextInfo & text1, const TextInfo & text2) const; // checked whether two pieces of text can be merged into one.
 
@@ -440,6 +446,10 @@ public:
 	bool		fontchanged() const { return ! textInfo_.samefont(lastTextInfo_); }
 	bool		textcolorchanged() const { return ! textInfo_.samecolor(lastTextInfo_); }
 
+	void		setColorName(const char * const name) {
+				textInfo_.colorName = name ;  
+			 	currentPath->colorName = name; 
+	}
 	void		setRGB(const float R,const float G, const float B)
 			{ 
 			 if ( ( R > 1.0 ) || ( G > 1.0 ) || ( B > 1.0 ) ||
@@ -500,7 +510,8 @@ public:
 
 	void 		dumpPath(bool doFlushText = true);  // shows current path
 
-	enum		flushmode_t { flushall, flushtext, flushpath };
+	//lint -esym(578,flushall)  // flushall hides same name in stdio
+	enum		flushmode_t { flushall, flushtext, flushpath }; 
 
 	void		flushOutStanding( flushmode_t flushmode = flushall);
 
@@ -540,13 +551,16 @@ public:
 
 	// the push*Text methods set the textinfo_ member and then call the 
 	// showOrMergeText(textinfo_) ;
-	void    	pushText(const char *const thetext,
+	void    	pushText(const size_t len,
+				        const char *const thetext,
 					const float x, 
-					const float y);
+					const float y,
+					const char * const glyphnames=0);
 
 	void		pushHEXText(const char *const thetext, 
 					const float x, 
-					const float y);
+					const float y,
+					const char * const glyphnames=0);
 
 	void		flushTextBuffer(bool useMergeBuffer); // flushes text from the text (merge) buffer 
 	void		showOrMergeText();
@@ -560,9 +574,9 @@ public:
 
 	// The next functions are virtual with a default empty implementation
 
-	virtual void    show_image(const PSImage & imageinfo) {
+	virtual void    show_image(const PSImage & /* imageinfo */) {
 		cerr << "show_image called, although backend does not support images" << endl;
-		unused(&imageinfo);
+		//unused(&imageinfo);
 	}
 
 	// if during construction something may go wrong, a backend can
@@ -593,6 +607,7 @@ protected:
 	float           fillR() const { return outputPath->fillR; } // fill colors
 	float           fillG() const { return outputPath->fillG; }
 	float           fillB() const { return outputPath->fillB; }
+	const RSString & currentColorName() const { return outputPath->colorName; }
 	const char *    dashPattern() const { return outputPath->dashPattern.value(); }
 	float           currentR() const { return outputPath->fillR; } // backends that don't support merging 
 	float           currentG() const { return outputPath->fillG; } // don't need to differentiate and
@@ -709,6 +724,7 @@ public:
 	// of memory needs to be done by the same dll which did the allocation.
 	// this is not simply achieved if plugins are loaded as DLL.
 	virtual void deleteyourself() { delete this; } 
+	virtual ~basedrawingelement() {}
 private:
 //	const unsigned int size;
 };
@@ -728,11 +744,11 @@ public:
 // "drvbase.h", line 455: sorry, not implemented: cannot expand inline function  drawingelement 
 //   <1 , 0 >::drawingelement__pt__19_XCUiL11XC5DtypeL10(Point*) with  for statement in inline
 
-	drawingelement(float x1 = 0.0 ,float y1 = 0.0 , float x2 = 0.0, float y2 = 0.0, float x3 = 0.0, float y3 = 0.0)
+	drawingelement(float x_1 = 0.0 ,float y_1 = 0.0 , float x_2 = 0.0, float y_2 = 0.0, float x_3 = 0.0, float y_3 = 0.0)
 	: basedrawingelement()
 	{
 #if defined (__GNUG__) || defined (_MSC_VER) && _MSC_VER >= 1100
-	const Point  p[] = {Point(x1,y1),Point(x2,y2),Point(x3,y3)};
+	const Point  p[] = {Point(x_1,y_1),Point(x_2,y_2),Point(x_3,y_3)};
 	copyPoints(nr,p,points);
 #else
 	// Turbo C++ hangs if the other solution is used.
@@ -740,9 +756,9 @@ public:
 	// so use this for all compilers besides GNU and MS VC++
 	// This, however, is somewhat slower than the solution above
 	Point  * p = new Point[3];
-	p[0] = Point(x1,y1);
-	p[1] = Point(x2,y2);
-	p[2] = Point(x3,y3);
+	p[0] = Point(x_1,y_1);
+	p[1] = Point(x_2,y_2);
+	p[2] = Point(x_3,y_3);
 	copyPoints(nr,p,points);
 	delete [] p;
 #endif
@@ -769,8 +785,11 @@ public:
 		return new drawingelement<nr,curtype>(*this);
 	}
 	const Point &getPoint(unsigned int i) const  { 
-		assert( (i+1) < (nr+1) );  // nr can be 0 - so unsigned i could never be < 0
-					   // but if nr==0, i==0 is also invalid. (logically i has to be <nr)
+#ifndef _lint
+		assert( (i+1) < (nr+1) );
+						// nr can be 0 - so unsigned i could never be < 0
+					    // but if nr==0, i==0 is also invalid. (logically i has to be <nr)
+#endif
 		return points[i]; 
 	}
 	virtual Dtype getType() const 		     { return (Dtype) curtype; }
@@ -930,12 +949,13 @@ public:
 
 	virtual unsigned int getdrvbaseVersion() const { return 0; } // this is only needed for the driverless backends (ps/dump/gs)
 
+	const char * const additionalInfo() const;
  // Data members
 	const char * const symbolicname;
 	const char * const short_explanation;
 	const char * const long_explanation;
 	const char * const suffix;
-	const char * const additionalInfo;
+
 	const bool 	backendSupportsSubPathes;
 	const bool 	backendSupportsCurveto;
 	const bool 	backendSupportsMerging; // merge a separate outline and filling of a polygon -> 1. element
@@ -945,7 +965,13 @@ public:
 	const bool	backendSupportsMultiplePages;
 	const bool	backendSupportsClipping;
 	const bool	nativedriver;
-	RSString filename; // where this driver is loaded from
+	RSString filename; 
+	// where this driver is loaded from
+	// Note: formerly this was a RSString - but that caused problems under X64 / Windows
+	// it seems as constructing and deleting heap during start-up phase when not all DLLs are fully initialized
+	// can cause these problems (well - I know then order of init among DLLs/SOs is not guaranteed by C++)
+	// But the passed strings are temporary - so we need to take a copy to the heap (without destroying it later -> small leak)
+
 	const checkfuncptr checkfunc;
 
 	static const char * currentfilename; // the name of the file from which the plugin is loaded
@@ -1013,8 +1039,10 @@ public:
 //	virtual void DeleteBackend(drvbase * & ptr) const { delete (T*) ptr; ptr = 0; }
 	virtual unsigned int getdrvbaseVersion() const { return drvbaseVersion; }
 
-private: typedef DriverDescriptionT<T> SHORTNAME;
-	NOCOPYANDASSIGN(SHORTNAME)
+private: 
+	// typedef DriverDescriptionT<T> SHORTNAME;
+	// NOCOPYANDASSIGN(SHORTNAME)
+	NOCOPYANDASSIGN(DriverDescriptionT<T>)
 };
 
 #if !( (defined (__GNUG__)  && (__GNUC__>=3) && defined (HAVESTL)) || defined (_MSC_VER) && (_MSC_VER >= 1300) )
